/*
 * (c) 2021, SWD Embedded Systems Limited, http://www.kpda.ru
 */


#include "f3s_spi.h"


extern f3s_flashcfg_t   flashcfg;

int main( int argc, char **argv )
{
    static f3s_service_t    service[] = { { sizeof(f3s_service_t),
                                            f3s_spi_open,
                                            f3s_spi_page,
                                            generic_status,
                                            f3s_spi_close },
                                          { 0, 0, 0, 0, 0  /* mandatory last entry */ } };

#if MTD_VER == 2
    static f3s_flash_v2_t   flash[] = { { sizeof( f3s_flash_v2_t ),
                                          f3s_spi_ident,        /* Ident */
                                          f3s_spi_reset,        /* Reset */

                                          /* v1 ReadWrite/Erase/Suspend/Resume/Sync (Unused)  */
                                          NULL, NULL, NULL, NULL, NULL, NULL,

                                          f3s_spi_v2read,       /* v2 Read (Use default) */
                                          f3s_spi_v2write,      /* v2 Write */
                                          f3s_spi_v2erase,      /* v2 Erase */
                                          NULL,                 /* v2 Suspend */
                                          NULL,                 /* v2 Resume */
                                          f3s_spi_v2sync,      /* v2 Sync */

                                          /* v2 Islock/Lock/Unlock/Unlockall (not supported)  */
                                          NULL, NULL, NULL, NULL },
                                        { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 /* mandatory last entry */ } };
#else
    static f3s_flash_t      flash[] = { { 0, 0, 0, 0, 0, 0, 0, 0, 0 /* mandatory last entry */ } };
#endif

    /* init f3s */
    f3s_init( argc, argv, (f3s_flash_t *)flash );

    /* Set bus width and interleave */
    set_flash_config( 8, 1 );
    flashcfg.bus_width    = 8;
    flashcfg.chip_inter   = 1;
    flashcfg.device_width = flashcfg.bus_width / flashcfg.chip_inter;

    /* start f3s */
    return f3s_start( service, (f3s_flash_t *)flash );
}
