/*
 * (c) 2021, SWD Embedded Systems Limited, http://www.kpda.ru
 */


#include <pthread.h>
#include "f3s_spi.h"


int32_t f3s_spi_open( f3s_socket_t *socket, uint32_t flags )
{
    if ( socket->memory )
        return (EOK);

    ThreadCtl( _NTO_TCTL_IO, 0 );
    if ( f3s_socket_option( socket ) )
    {
        printf( "You must use the -s option to pass in spi device number and chip select\n" );
        exit( 1 );
    }

    s25_spi_t   *spi = calloc( 1, sizeof( s25_spi_t ) );

    spi->devnum = socket->address;      /* using socket address field for spi device number */
    spi->cs     = socket->window_size;  /* using socket window_size field for spi chip select */

    if ( s25_spi_init( spi ) )
    {
        printf( "SPI init error\n" );
        exit( 1 );
    }

    socket->memory = (_Uint8t *)spi;

    char    data[5];
    s25_spi_id( socket->memory, data, 5 );
    printf( "SPI flash: Manufacturer ID = 0x%02X, Device ID = 0x%02X%02X \n", data[0], data[1], data[2] );

    socket->name        = (unsigned char *)"SPI serial flash";
    socket->window_size = socket->array_size = TOTAL_SIZE_BYTES;

    if ( nanospin_calibrate( 0 ) != EOK )
        fprintf( stderr, "(devf  t%d::%s:%d) nanospin calibration failed!\n", pthread_self(), __func__, __LINE__ );

    return EOK;
}
